@@ -6,6 +6,7 @@ import asyncpg
 from sqlalchemy.dialects.postgresql import pypostgresql
 from sqlalchemy.engine.interfaces import Dialect
 from sqlalchemy.sql import ClauseElement
+from sqlalchemy.sql.schema import Column
 
 from databases.core import DatabaseURL
 from databases.interfaces import ConnectionBackend, DatabaseBackend, TransactionBackend
@@ -73,9 +74,16 @@ class Record(Mapping):
             column_name: (idx, datatype)
             for idx, (column_name, _, _, datatype) in enumerate(self._result_columns)
         }
+        self._column_map_full = {
+            str(column[0]): (idx, datatype)
+            for idx, (_, _, column, datatype) in enumerate(self._result_columns)
+        }
 
-    def __getitem__(self, key: str) -> typing.Any:
-        idx, datatype = self._column_map[key]
+    def __getitem__(self, key: typing.Any) -> typing.Any:
+        if type(key) is Column:
+            idx, datatype = self._column_map_full[str(key)]
+        else:
+            idx, datatype = self._column_map[key]
         raw = self._row[idx]
         try:
             processor = _result_processors[datatype]
@@ -168,9 +176,14 @@ class PostgresConnection(ConnectionBackend):
             for key, val in compiled_params
         ]
 
-        logger.debug(compiled_query, args)
+        logger.debug("Query: %s\nArgs: %s", compiled_query, args)
         return compiled_query, args, compiled._result_columns
 
+    @property
+    def raw_connection(self) -> asyncpg.connection.Connection:
+        assert self._connection is not None, "Connection is not acquired"
+        return self._connection
+
 
 class PostgresTransaction(TransactionBackend):
     def __init__(self, connection: PostgresConnection):
